@@ -773,7 +773,8 @@ class PlacementAPIClient(object):
                     resource_provider=rp_uuid, consumer=consumer_uuid)
             # Count new min_kbps values based on the diff in alloc_diff
             for drctn, min_kbps_diff in minbw_alloc_diff.items():
-                orig_kbps = body['allocations'][rp_uuid]['resources'][drctn]
+                orig_kbps = (body['allocations'][rp_uuid][
+                    'resources'].get(drctn, 0))
                 new_kbps = orig_kbps + min_kbps_diff
                 if new_kbps > 0:
                     body['allocations'][rp_uuid]['resources'][drctn] = new_kbps
@@ -781,10 +782,12 @@ class PlacementAPIClient(object):
                     # Remove the resource class if the new value for min_kbps
                     # is 0
                     resources = body['allocations'][rp_uuid]['resources']
-                    if len(resources) > 1:
-                        resources.pop(drctn, None)
-                    else:
-                        body['allocations'].pop(rp_uuid)
+                    resources.pop(drctn, None)
+
+            # Remove RPs without any resources
+            body['allocations'] = {
+                rp: alloc for rp, alloc in body['allocations'].items()
+                if alloc.get('resources')}
             try:
                 # Update allocations has no return body, but leave the loop
                 return self.update_allocation(consumer_uuid, body)
